@@ -1,23 +1,32 @@
 # -*- coding: utf-8 -*-
 
 import os
-import shutil
 import pickle
-from tests import TestCase, DATA_DIR
-from mutagen.id3 import ID3FileType, ID3
+
+from mutagen import MutagenError
+from mutagen.id3 import ID3FileType, ID3, RVA2
 from mutagen.easyid3 import EasyID3, error as ID3Error
 from mutagen._compat import PY3
-from tempfile import mkstemp
+
+from tests import TestCase, DATA_DIR, get_temp_copy
 
 
 class TEasyID3(TestCase):
 
     def setUp(self):
-        fd, self.filename = mkstemp('.mp3')
-        os.close(fd)
-        empty = os.path.join(DATA_DIR, 'emptyfile.mp3')
-        shutil.copy(empty, self.filename)
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'emptyfile.mp3'))
         self.id3 = EasyID3()
+        self.realid3 = self.id3._EasyID3__id3
+
+    def tearDown(self):
+        os.unlink(self.filename)
+
+    def test_txxx_latin_first_then_non_latin(self):
+        self.id3["performer"] = [u"foo"]
+        self.id3["performer"] = [u"\u0243"]
+        self.id3.save(self.filename)
+        new = EasyID3(self.filename)
+        self.assertEqual(new["performer"], [u"\u0243"])
 
     def test_remember_ctr(self):
         empty = os.path.join(DATA_DIR, 'emptyfile.mp3')
@@ -58,7 +67,7 @@ class TEasyID3(TestCase):
 
     def test_nonexistent_file(self):
         empty = os.path.join(DATA_DIR, 'does', 'not', 'exist')
-        self.assertRaises(IOError, EasyID3, filename=empty)
+        self.assertRaises(MutagenError, EasyID3, filename=empty)
 
     def test_write_single(self):
         for key in EasyID3.valid_keys:
@@ -189,7 +198,7 @@ class TEasyID3(TestCase):
         self.failUnless("performer:bar" in self.id3)
         del(self.id3["performer:bar"])
         self.failIf("performer:bar" in self.id3)
-        self.failIf("TMCL" in self.id3._EasyID3__id3)
+        self.failIf("TMCL" in self.realid3)
 
     def test_performer_delete_dne(self):
         self.failUnlessRaises(KeyError, self.id3.__delitem__, "performer:bar")
@@ -205,7 +214,7 @@ class TEasyID3(TestCase):
         self.id3["asin"] = "Hello"
         self.failUnless("asin" in self.id3.keys())
         self.failUnlessEqual(self.id3["asin"], ["Hello"])
-        self.failUnless("TXXX:ASIN" in self.id3._EasyID3__id3)
+        self.failUnless("TXXX:ASIN" in self.realid3)
 
     def test_txxx_del_set_del(self):
         self.failIf("asin" in self.id3.keys())
@@ -230,11 +239,11 @@ class TEasyID3(TestCase):
     def test_bad_trackid(self):
         self.failUnlessRaises(ValueError, self.id3.__setitem__,
                               "musicbrainz_trackid", ["a", "b"])
-        self.failIf(self.id3._EasyID3__id3.getall("RVA2"))
+        self.failIf(self.realid3.getall("RVA2"))
 
     def test_gain_bad_key(self):
         self.failIf("replaygain_foo_gain" in self.id3)
-        self.failIf(self.id3._EasyID3__id3.getall("RVA2"))
+        self.failIf(self.realid3.getall("RVA2"))
 
     def test_gain_bad_value(self):
         self.failUnlessRaises(
@@ -244,11 +253,11 @@ class TEasyID3(TestCase):
         self.failUnlessRaises(
             ValueError,
             self.id3.__setitem__, "replaygain_foo_gain", ["1", "2"])
-        self.failIf(self.id3._EasyID3__id3.getall("RVA2"))
+        self.failIf(self.realid3.getall("RVA2"))
 
     def test_peak_bad_key(self):
         self.failIf("replaygain_foo_peak" in self.id3)
-        self.failIf(self.id3._EasyID3__id3.getall("RVA2"))
+        self.failIf(self.realid3.getall("RVA2"))
 
     def test_peak_bad_value(self):
         self.failUnlessRaises(
@@ -260,7 +269,7 @@ class TEasyID3(TestCase):
             self.id3.__setitem__, "replaygain_foo_peak", ["1", "1"])
         self.failUnlessRaises(
             ValueError, self.id3.__setitem__, "replaygain_foo_peak", ["3"])
-        self.failIf(self.id3._EasyID3__id3.getall("RVA2"))
+        self.failIf(self.realid3.getall("RVA2"))
 
     def test_gain_peak_get(self):
         self.id3["replaygain_foo_gain"] = "+3.5 dB"
@@ -300,6 +309,35 @@ class TEasyID3(TestCase):
         self.failIf("replaygain_foo_gain" in self.id3.keys())
         self.failIf("replaygain_bar_gain" in self.id3.keys())
 
+    def test_gain_peak_capitalization(self):
+        frame = RVA2(desc=u"Foo", gain=1.0, peak=1.0, channel=0)
+        self.assertFalse(len(self.realid3))
+        self.realid3.add(frame)
+        self.assertTrue("replaygain_Foo_peak" in self.id3)
+        self.assertTrue("replaygain_Foo_peak" in self.id3.keys())
+        self.assertTrue("replaygain_Foo_gain" in self.id3)
+        self.assertTrue("replaygain_Foo_gain" in self.id3.keys())
+
+        self.id3["replaygain_Foo_gain"] = ["0.5"]
+        self.id3["replaygain_Foo_peak"] = ["0.25"]
+
+        frames = self.realid3.getall("RVA2")
+        self.assertEqual(len(frames), 1)
+        self.assertEqual(frames[0].desc, u"Foo")
+        self.assertEqual(frames[0].gain, 0.5)
+        self.assertEqual(frames[0].peak, 0.25)
+
+    def test_case_insensitive(self):
+        self.id3["date"] = [u"2004"]
+        self.assertEqual(self.id3["DATE"], [u"2004"])
+        del self.id3["DaTe"]
+        self.assertEqual(len(self.id3), 0)
+
+        self.id3["asin"] = [u"foo"]
+        self.assertEqual(self.id3["Asin"], [u"foo"])
+        del self.id3["AsIn"]
+        self.assertEqual(len(self.id3), 0)
+
     def test_pickle(self):
         # https://github.com/quodlibet/mutagen/issues/102
         pickle.dumps(self.id3)
@@ -347,5 +385,9 @@ class TEasyID3(TestCase):
         self.id3.ListFallback = list_func
         self.failUnlessEqual(self.id3.keys(), ["somekey"])
 
-    def tearDown(self):
-        os.unlink(self.filename)
+    def test_text_tags(self):
+        for tag in ["albumartist", "performer"]:
+            self.id3[tag] = u"foo"
+            self.id3.save(self.filename)
+            id3 = EasyID3(self.filename)
+            self.failUnlessEqual(id3[tag], [u"foo"])
