@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
 
-import shutil
 import os
 import subprocess
-from tempfile import mkstemp
-
-from tests import TestCase, DATA_DIR
 
+from mutagen import MutagenError
 from mutagen.id3 import ID3, TIT2, ID3NoHeaderError
 from mutagen.flac import to_int_be, Padding, VCFLACDict, MetadataBlock, error
 from mutagen.flac import StreamInfo, SeekTable, CueSheet, FLAC, delete, Picture
 from mutagen._compat import PY3
+
+from tests import TestCase, DATA_DIR, get_temp_copy
 from tests.test__vorbis import TVCommentDict, VComment
 
 
@@ -283,9 +282,7 @@ class TFLAC(TestCase):
     SAMPLE = os.path.join(DATA_DIR, "silence-44-s.flac")
 
     def setUp(self):
-        fd, self.NEW = mkstemp(".flac")
-        os.close(fd)
-        shutil.copy(self.SAMPLE, self.NEW)
+        self.NEW = get_temp_copy(self.SAMPLE)
         self.flac = FLAC(self.NEW)
 
     def tearDown(self):
@@ -364,8 +361,9 @@ class TFLAC(TestCase):
     def test_write_nochange(self):
         f = FLAC(self.NEW)
         f.save()
-        self.failUnlessEqual(open(self.SAMPLE, "rb").read(),
-                             open(self.NEW, "rb").read())
+        with open(self.SAMPLE, "rb") as a:
+            with open(self.NEW, "rb") as b:
+                self.failUnlessEqual(a.read(), b.read())
 
     def test_write_changetitle(self):
         f = FLAC(self.NEW)
@@ -438,8 +436,8 @@ class TFLAC(TestCase):
     def test_ooming_vc_header(self):
         # issue 112: Malformed FLAC Vorbis header causes out of memory error
         # https://github.com/quodlibet/mutagen/issues/112
-        self.assertRaises(IOError, FLAC, os.path.join(DATA_DIR,
-                                                      'ooming-header.flac'))
+        self.assertRaises(error, FLAC, os.path.join(DATA_DIR,
+                                                    'ooming-header.flac'))
 
     def test_with_real_flac(self):
         if not have_flac:
@@ -464,20 +462,20 @@ class TFLAC(TestCase):
     def test_two_vorbis_blocks(self):
         self.flac.metadata_blocks.append(self.flac.metadata_blocks[1])
         self.flac.save()
-        self.failUnlessRaises(IOError, FLAC, self.NEW)
+        self.failUnlessRaises(error, FLAC, self.NEW)
 
     def test_missing_streaminfo(self):
         self.flac.metadata_blocks.pop(0)
         self.flac.save()
-        self.failUnlessRaises(IOError, FLAC, self.NEW)
+        self.failUnlessRaises(error, FLAC, self.NEW)
 
     def test_load_invalid_flac(self):
         self.failUnlessRaises(
-            IOError, FLAC, os.path.join(DATA_DIR, "xing.mp3"))
+            error, FLAC, os.path.join(DATA_DIR, "xing.mp3"))
 
     def test_save_invalid_flac(self):
         self.failUnlessRaises(
-            IOError, self.flac.save, os.path.join(DATA_DIR, "xing.mp3"))
+            error, self.flac.save, os.path.join(DATA_DIR, "xing.mp3"))
 
     def test_pprint(self):
         self.failUnless(self.flac.pprint())
@@ -556,7 +554,7 @@ class TFLACFile(TestCase):
         """mutagen 1.2 raises UnboundLocalError, then it tries to open
         non-existant FLAC files"""
         filename = os.path.join(DATA_DIR, "doesntexist.flac")
-        self.assertRaises(IOError, FLAC, filename)
+        self.assertRaises(MutagenError, FLAC, filename)
 
 
 class TFLACBadBlockSize(TestCase):
@@ -585,9 +583,7 @@ class TFLACBadBlockSizeWrite(TestCase):
     TOO_SHORT = os.path.join(DATA_DIR, "52-too-short-block-size.flac")
 
     def setUp(self):
-        fd, self.NEW = mkstemp(".flac")
-        os.close(fd)
-        shutil.copy(self.TOO_SHORT, self.NEW)
+        self.NEW = get_temp_copy(self.TOO_SHORT)
 
     def tearDown(self):
         os.unlink(self.NEW)
@@ -598,16 +594,16 @@ class TFLACBadBlockSizeWrite(TestCase):
         flac.save()
         flac2 = FLAC(self.NEW)
         self.failUnlessEqual(flac["title"], flac2["title"])
-        data = open(self.NEW, "rb").read(1024)
+        with open(self.NEW, "rb") as h:
+            data = h.read(1024)
         self.failIf(b"Tunng" in data)
 
 
 class TFLACBadBlockSizeOverflow(TestCase):
 
     def setUp(self):
-        fd, self.filename = mkstemp(".flac")
-        os.close(fd)
-        shutil.copy(os.path.join(DATA_DIR, "silence-44-s.flac"), self.filename)
+        self.filename = get_temp_copy(
+            os.path.join(DATA_DIR, "silence-44-s.flac"))
 
     def tearDown(self):
         os.unlink(self.filename)
@@ -645,77 +641,6 @@ class TFLACBadBlockSizeOverflow(TestCase):
         f.save()
 
 
-class CVE20074619(TestCase):
-
-    # Tests to ensure Mutagen is not vulnerable to a number of security
-    # issues found in libFLAC.
-    # http://research.eeye.com/html/advisories/published/AD20071115.html
-
-    def test_1(self):
-        # "Editing any Metadata Block Size value to a large value such
-        # as 0xFFFFFFFF may result in a heap based overflow in the
-        # decoding software."
-        filename = os.path.join(DATA_DIR, "CVE-2007-4619-1.flac")
-        self.failUnlessRaises(IOError, FLAC, filename)
-        # work around https://bitbucket.org/pypy/pypy/issue/1988
-        import gc
-        gc.collect()
-
-    def test_2(self):
-        # "The second vulnerability lies within the parsing of any
-        # VORBIS Comment String Size fields. Settings this fields to
-        # an overly large size, such as 0xFFFFFFF, could also result
-        # in another heap-based overflow allowing arbitrary code to
-        # execute in the content of the decoding program."
-        filename = os.path.join(DATA_DIR, "CVE-2007-4619-2.flac")
-        self.failUnlessRaises(IOError, FLAC, filename)
-        # work around https://bitbucket.org/pypy/pypy/issue/1988
-        import gc
-        gc.collect()
-
-    # "By inserting an overly long VORBIS Comment data string along
-    # with an large VORBIS Comment data string size value (such as
-    # 0x000061A8 followed by 25,050 A's), applications that do not
-    # properly apply boundary checks will result in a stack-based
-    # buffer overflow."
-    #
-    # This is tested, among other places, in
-    # test_save_grown_split_setup_packet_reference which saves a
-    # comment field of 200K in size.
-
-    # Vulnerabilities 4-10 are the same thing for the picture block.
-
-    # Vulnerability 11 does not apply to Mutagen as it does not
-    # download images when given a redirect MIME type.
-
-    # "An overly large Padding length field value would set the basis
-    # for another heap overflow inside a vulnerable application. By
-    # setting this value to a large value such as 0xFFFFFFFF, a
-    # malformed FLAC file could cause a heap based corruption scenario
-    # when the memory for the Padding length is calculated without
-    # proper bounds checks."
-
-    # We should raise an IOError when trying to write such large
-    # blocks, or when reading blocks with an incorrect padding length.
-    # Although, I do wonder about the correctness of this
-    # vulnerability, since a padding length of 0xFFFFFFFF is
-    # impossible to store in a FLAC file.
-
-    def test_12_read(self):
-        filename = os.path.join(DATA_DIR, "CVE-2007-4619-12.flac")
-        self.failUnlessRaises(IOError, FLAC, filename)
-
-    def test_12_write_too_big(self):
-        filename = os.path.join(DATA_DIR, "silence-44-s.flac")
-        f = FLAC(filename)
-        # This size is too big to be an integer.
-        f.metadata_blocks[-1].length = 0xFFFFFFFFFFFFFFFF
-        self.failUnlessRaises(IOError, f.metadata_blocks[-1].write)
-
-    # Vulnerability 13 and 14 are specific to libFLAC and C/C++ memory
-    # management schemes.
-
-
 have_flac = True
 try:
     call_flac()
