@@ -123,6 +123,16 @@ class TMid3v2(_TTools):
         self.failUnlessEqual(frame.desc, "A\\")
         self.failUnlessEqual(frame.text, ["B:C"])
 
+    def test_ufid(self):
+        res, out, err = self.call2(
+            fsn(u"--UFID"), fsn(u"foo:bar"), self.filename)
+        self.assertEqual((res, out, err), (0, "", ""))
+
+        f = ID3(self.filename)
+        frame = f.getall("UFID:foo")[0]
+        self.assertEqual(frame.owner, u"foo")
+        self.assertEqual(frame.data, b"bar")
+
     def test_comm1(self):
         res, out = self.call(fsn(u"--COMM"), fsn(u"A"), self.filename)
         self.failUnlessEqual((res, out), (0, ""))
@@ -162,6 +172,27 @@ class TMid3v2(_TTools):
         self.failUnlessEqual(frame.text, ["B:C:D"])
         self.failUnlessEqual(frame.lang, "ger")
 
+    def test_apic(self):
+        image_path = os.path.join(DATA_DIR, "image.jpg")
+        image_path = os.path.relpath(image_path)
+        res, out, err = self.call2(
+            fsn(u"--APIC"), image_path + fsn(u":fooAPIC:3:image/jpeg"),
+            self.filename)
+        self.failUnlessEqual((res, out, err), (0, "", ""))
+
+        with open(image_path, "rb") as h:
+            data = h.read()
+
+        f = ID3(self.filename)
+        frame = f.getall("APIC:fooAPIC")[0]
+        self.assertEqual(frame.desc, u"fooAPIC")
+        self.assertEqual(frame.mime, "image/jpeg")
+        self.assertEqual(frame.data, data)
+
+        res, out = self.call(fsn(u"--list"), self.filename)
+        self.assertEqual(res, 0)
+        self.assertTrue("fooAPIC" in out)
+
     def test_encoding_with_escape(self):
         is_bytes = PY2 and os.name != "nt"
 
